"use client"

import { useState, useEffect } from "react"
import Link from "next/link"
import { useRouter } from "next/navigation"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Badge } from "@/components/ui/badge"
import {
  GraduationCap,
  Plus,
  Clock,
  CheckCircle,
  AlertCircle,
  MessageSquare,
  CreditCard,
  User,
  Settings,
  LogOut,
  RefreshCw,
} from "lucide-react"
import { NotificationBanner } from "@/components/notification-banner"
import { getAuthenticatedUser, logout, hasRole } from "@/lib/auth"
import { useOrdersByClient, useStats } from "@/hooks/use-data-store"

export default function ClientDashboard() {
  const router = useRouter()
  const [user, setUser] = useState<any>(null)
  const [isLoading, setIsLoading] = useState(true)

  // Get orders for this client
  const orders = useOrdersByClient(user?.email || "")
  const stats = useStats()

  useEffect(() => {
    const authenticatedUser = getAuthenticatedUser()

    if (!authenticatedUser || !hasRole("client")) {
      router.push("/auth/login")
      return
    }

    setUser(authenticatedUser)
    setIsLoading(false)
  }, [router])

  const handleLogout = () => {
    logout()
  }

  const getStatusBadge = (status: string) => {
    switch (status) {
      case "pending":
        return (
          <Badge variant="secondary">
            <Clock className="w-3 h-3 mr-1" />
            Pending
          </Badge>
        )
      case "payment_pending":
        return (
          <Badge variant="outline" className="border-yellow-500 text-yellow-700">
            <CreditCard className="w-3 h-3 mr-1" />
            Payment Pending
          </Badge>
        )
      case "paid":
        return (
          <Badge variant="default">
            <CheckCircle className="w-3 h-3 mr-1" />
            Paid
          </Badge>
        )
      case "assigned":
        return (
          <Badge variant="default">
            <User className="w-3 h-3 mr-1" />
            Writer Assigned
          </Badge>
        )
      case "in_progress":
        return (
          <Badge variant="default">
            <AlertCircle className="w-3 h-3 mr-1" />
            In Progress
          </Badge>
        )
      case "revision":
        return (
          <Badge variant="outline" className="border-yellow-500 text-yellow-700">
            <RefreshCw className="w-3 h-3 mr-1" />
            Revision
          </Badge>
        )
      case "completed":
        return (
          <Badge variant="secondary" className="bg-green-100 text-green-800">
            <CheckCircle className="w-3 h-3 mr-1" />
            Completed
          </Badge>
        )
      default:
        return <Badge variant="outline">{status}</Badge>
    }
  }

  // Calculate client-specific stats
  const clientStats = {
    totalOrders: orders.length,
    inProgress: orders.filter((o) => o.status === "in_progress" || o.status === "assigned").length,
    completed: orders.filter((o) => o.status === "completed").length,
    totalSpent: orders.filter((o) => o.status === "completed").reduce((sum, o) => sum + o.amount, 0),
  }

  if (isLoading) {
    return (
      <div className="min-h-screen bg-gray-50 flex items-center justify-center">
        <div className="text-center">
          <div className="animate-spin rounded-full h-12 w-12 border-b-2 border-primary mx-auto mb-4"></div>
          <p>Loading dashboard...</p>
        </div>
      </div>
    )
  }

  return (
    <div className="min-h-screen dashboard-academic">
      {/* Header */}
      <header className="dashboard-header-academic">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="flex justify-between items-center py-6">
            <div className="flex items-center">
              <div className="w-10 h-10 bg-primary rounded-xl flex items-center justify-center">
                <GraduationCap className="h-6 w-6 text-white" />
              </div>
              <span className="ml-3 text-xl font-bold text-gray-900">ProEssayWorks</span>
            </div>
            <div className="flex items-center space-x-6">
              <span className="body-academic-regular text-gray-600">
                Welcome back, <span className="font-semibold text-gray-900">{user?.name}</span>
              </span>
              <div className="flex items-center space-x-2">
                <Button variant="ghost" size="sm" className="font-medium">
                  <MessageSquare className="h-4 w-4 mr-2" />
                  Messages
                </Button>
                <Button variant="ghost" size="sm" className="font-medium">
                  <User className="h-4 w-4 mr-2" />
                  Profile
                </Button>
                <Button variant="ghost" size="sm" className="font-medium">
                  <Settings className="h-4 w-4 mr-2" />
                  Settings
                </Button>
                <Button
                  variant="ghost"
                  size="sm"
                  onClick={handleLogout}
                  className="font-medium text-red-600 hover:text-red-700"
                >
                  <LogOut className="h-4 w-4 mr-2" />
                  Logout
                </Button>
              </div>
            </div>
          </div>
        </div>
      </header>

      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-8">
        {/* Welcome Section */}
        <div className="mb-12">
          <h1 className="heading-academic-secondary text-gray-900 mb-3">Welcome back, {user?.name}!</h1>
          <p className="body-academic-large text-gray-600">Manage your orders and track your academic progress</p>
        </div>

        {/* Add Notification Banner */}
        <NotificationBanner />

        {/* Stats Cards */}
        <div className="grid grid-cols-1 md:grid-cols-4 gap-6 mb-12">
          <Card className="dashboard-card-academic">
            <CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
              <CardTitle className="body-academic-regular font-medium text-gray-600">Total Orders</CardTitle>
              <GraduationCap className="h-5 w-5 text-gray-400" />
            </CardHeader>
            <CardContent>
              <div className="text-3xl font-bold text-gray-900">{clientStats.totalOrders}</div>
              <p className="body-academic-small text-gray-500 mt-1">
                {clientStats.totalOrders === 0 ? "Start by placing your first order" : "All time orders"}
              </p>
            </CardContent>
          </Card>
          <Card className="dashboard-card-academic">
            <CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
              <CardTitle className="body-academic-regular font-medium text-gray-600">In Progress</CardTitle>
              <Clock className="h-5 w-5 text-gray-400" />
            </CardHeader>
            <CardContent>
              <div className="text-3xl font-bold text-gray-900">{clientStats.inProgress}</div>
              <p className="body-academic-small text-gray-500 mt-1">
                {clientStats.inProgress === 0 ? "No active orders" : "Currently being worked on"}
              </p>
            </CardContent>
          </Card>
          <Card className="dashboard-card-academic">
            <CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
              <CardTitle className="body-academic-regular font-medium text-gray-600">Completed</CardTitle>
              <CheckCircle className="h-5 w-5 text-gray-400" />
            </CardHeader>
            <CardContent>
              <div className="text-3xl font-bold text-gray-900">{clientStats.completed}</div>
              <p className="body-academic-small text-gray-500 mt-1">
                {clientStats.completed === 0 ? "No completed orders yet" : "Successfully delivered"}
              </p>
            </CardContent>
          </Card>
          <Card className="dashboard-card-academic">
            <CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
              <CardTitle className="body-academic-regular font-medium text-gray-600">Total Spent</CardTitle>
              <CreditCard className="h-5 w-5 text-gray-400" />
            </CardHeader>
            <CardContent>
              <div className="text-3xl font-bold text-gray-900">${clientStats.totalSpent}</div>
              <p className="body-academic-small text-gray-500 mt-1">
                {clientStats.totalSpent === 0 ? "No orders placed yet" : "Investment in education"}
              </p>
            </CardContent>
          </Card>
        </div>

        {/* Main Content */}
        <div className="grid grid-cols-1 lg:grid-cols-3 gap-8">
          <div className="lg:col-span-2">
            <Card className="dashboard-card-academic">
              <CardHeader className="flex flex-row items-center justify-between">
                <div>
                  <CardTitle className="heading-academic-tertiary">My Orders</CardTitle>
                  <CardDescription className="body-academic-regular text-gray-600">
                    Track and manage your academic writing orders
                  </CardDescription>
                </div>
                <Link href="/client/place-order">
                  <Button className="btn-academic-primary">
                    <Plus className="h-4 w-4 mr-2" />
                    New Order
                  </Button>
                </Link>
              </CardHeader>
              <CardContent>
                {orders.length === 0 ? (
                  <div className="text-center py-12">
                    <GraduationCap className="h-16 w-16 text-gray-300 mx-auto mb-4" />
                    <h3 className="text-lg font-semibold text-gray-900 mb-2">No orders yet</h3>
                    <p className="text-gray-600 mb-6">Start by placing your first academic writing order</p>
                    <Link href="/client/place-order">
                      <Button className="btn-academic-primary">
                        <Plus className="h-4 w-4 mr-2" />
                        Place Your First Order
                      </Button>
                    </Link>
                  </div>
                ) : (
                  <div className="space-y-4">
                    {orders.map((order) => (
                      <div key={order.id} className="border rounded-lg p-4 hover:bg-gray-50 transition-colors">
                        <div className="flex justify-between items-start mb-2">
                          <div>
                            <h3 className="font-semibold text-lg">{order.title}</h3>
                            <p className="text-sm text-gray-600">Order ID: {order.id}</p>
                          </div>
                          {getStatusBadge(order.status)}
                        </div>
                        <div className="grid grid-cols-2 md:grid-cols-4 gap-4 text-sm text-gray-600 mb-3">
                          <div>
                            <span className="font-medium">Pages:</span> {order.pages}
                          </div>
                          <div>
                            <span className="font-medium">Deadline:</span>{" "}
                            {new Date(order.deadline).toLocaleDateString()}
                          </div>
                          <div>
                            <span className="font-medium">Amount:</span> ${order.amount}
                          </div>
                          <div>
                            <span className="font-medium">Writer:</span> {order.writerName || "Not assigned"}
                          </div>
                          {order.status === "in_progress" && (
                            <div className="col-span-2">
                              <span className="font-medium">Progress:</span> {order.progress}%
                              <div className="w-full bg-gray-200 rounded-full h-2 mt-1">
                                <div
                                  className="bg-primary h-2 rounded-full transition-all duration-300"
                                  style={{ width: `${order.progress}%` }}
                                ></div>
                              </div>
                            </div>
                          )}
                        </div>
                        <div className="flex space-x-2">
                          <Button variant="outline" size="sm">
                            View Details
                          </Button>
                          {(order.status === "in_progress" || order.status === "assigned") && order.writerName && (
                            <Button variant="outline" size="sm">
                              <MessageSquare className="h-3 w-3 mr-1" />
                              Message Writer
                            </Button>
                          )}
                          {order.status === "payment_pending" && (
                            <Button size="sm" className="btn-academic-primary">
                              Complete Payment
                            </Button>
                          )}
                        </div>
                      </div>
                    ))}
                  </div>
                )}
              </CardContent>
            </Card>
          </div>

          <div className="space-y-6">
            {/* Quick Actions */}
            <Card className="dashboard-card-academic">
              <CardHeader>
                <CardTitle className="heading-academic-tertiary">Quick Actions</CardTitle>
              </CardHeader>
              <CardContent className="space-y-3">
                <Link href="/client/place-order">
                  <Button className="w-full justify-start btn-academic-primary">
                    <Plus className="h-4 w-4 mr-2" />
                    Place New Order
                  </Button>
                </Link>
                <Button variant="outline" className="w-full justify-start">
                  <MessageSquare className="h-4 w-4 mr-2" />
                  View Messages
                </Button>
                <Button variant="outline" className="w-full justify-start">
                  <CreditCard className="h-4 w-4 mr-2" />
                  Payment History
                </Button>
                <Button variant="outline" className="w-full justify-start">
                  <User className="h-4 w-4 mr-2" />
                  Update Profile
                </Button>
              </CardContent>
            </Card>

            {/* Recent Activity */}
            <Card className="dashboard-card-academic">
              <CardHeader>
                <CardTitle className="heading-academic-tertiary">Recent Activity</CardTitle>
              </CardHeader>
              <CardContent>
                {orders.length === 0 ? (
                  <div className="text-center py-8 text-gray-500">
                    <Clock className="h-12 w-12 mx-auto mb-4 text-gray-300" />
                    <p>No recent activity</p>
                    <p className="text-sm">Your activity will appear here</p>
                  </div>
                ) : (
                  <div className="space-y-3">
                    {orders.slice(0, 5).map((order) => (
                      <div key={order.id} className="flex items-center space-x-3 p-2 border rounded">
                        <div className="flex-shrink-0">
                          {order.status === "completed" ? (
                            <CheckCircle className="h-4 w-4 text-green-600" />
                          ) : order.status === "in_progress" ? (
                            <Clock className="h-4 w-4 text-blue-600" />
                          ) : (
                            <AlertCircle className="h-4 w-4 text-yellow-600" />
                          )}
                        </div>
                        <div className="flex-1 min-w-0">
                          <p className="text-sm font-medium text-gray-900 truncate">{order.title}</p>
                          <p className="text-xs text-gray-500">
                            {order.status === "completed"
                              ? "Completed"
                              : order.status === "in_progress"
                                ? `${order.progress}% complete`
                                : order.status === "assigned"
                                  ? "Writer assigned"
                                  : "Pending"}
                          </p>
                        </div>
                        <div className="text-xs text-gray-400">{new Date(order.lastUpdate).toLocaleDateString()}</div>
                      </div>
                    ))}
                  </div>
                )}
              </CardContent>
            </Card>
          </div>
        </div>
      </div>
    </div>
  )
}
